@@ -62,7 +62,8 @@ get_params <- function(x) {
 }
 
 link_help_page <- function(x) {
-  glue::glue("<a href='https://ymlthis.r-lib.org//reference/{x}.html'>{x}</a>")
+  url <- "https://ymlthis.r-lib.org/"
+  glue::glue("<a href='{url}/reference/{x}.html'>{x}</a>")
 } 
 
 filter_kable <- function(.tbl, .pattern = NULL, caption = NULL) {
